<?php

namespace Litecms\BookingManagement\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Litecms\BookingManagement\Models\BookingManagement;

class BookingManagementAction
{
    /**
     * Perform the complete action.
     *
     * @param BookingManagement $booking_management
     *
     * @return BookingManagement
     */
    public function complete(BookingManagement $booking_management)
    {
        try {
            $booking_management->status = 'complete';
            return $booking_management->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param BookingManagement $booking_management
     *
     * @return BookingManagement
     */public function verify(BookingManagement $booking_management)
    {
        try {
            $booking_management->status = 'verify';
            return $booking_management->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param BookingManagement $booking_management
     *
     * @return BookingManagement
     */public function approve(BookingManagement $booking_management)
    {
        try {
            $booking_management->status = 'approve';
            return $booking_management->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param BookingManagement $booking_management
     *
     * @return BookingManagement
     */public function publish(BookingManagement $booking_management)
    {
        try {
            $booking_management->status = 'publish';
            return $booking_management->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param BookingManagement $booking_management
     *
     * @return BookingManagement
     */
    public function archive(BookingManagement $booking_management)
    {
        try {
            $booking_management->status = 'archive';
            return $booking_management->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param BookingManagement $booking_management
     *
     * @return BookingManagement
     */
    public function unpublish(BookingManagement $booking_management)
    {
        try {
            $booking_management->status = 'unpublish';
            return $booking_management->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
